@@ -3,7 +3,7 @@ package POE::Wheel::ReadWrite;
 use strict;
 
 use vars qw($VERSION @ISA);
-$VERSION = '1.299'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.350'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw( croak carp );
 use POE qw(Wheel Driver::SysRW Filter::Line);
@@ -774,7 +774,7 @@ L<POE::Driver::SysRW>, which implements sysread() and syswrite(), is the
 default.  It's used in nearly all cases, so there's no point in
 specifying it.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head4 Filter
 
@@ -783,14 +783,14 @@ input data and the serializer it uses to prepare data for writing.  It
 defaults to a new L<POE::Filter::Line> instance since many network
 protocols are line based.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head4 InputFilter
 
 InputFilter and OutputFilter may be used to specify different filters
 for input and output.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head4 OutputFilter
 
@@ -942,7 +942,7 @@ HighEvent and LowEvent are used along with HighMark and LowMark to
 control the flow of streamed output.  Please see L</HighEvent> for
 more information and examples.
 
-TODO - Example here.
+Z<TODO - Example here.>
 
 =head2 put RECORDS
 
@@ -971,7 +971,7 @@ generates the event.  So for example, stopping InputEvent will also
 stop reading from the filehandle.  L</pause_input> and
 L</resume_input> may be a better way to manage input events, however.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 set_filter POE_FILTER
 
@@ -988,7 +988,7 @@ Switching filters can be tricky.  Please see the discussion of
 get_pending() in L<POE::Filter>.  Some filters may not support being
 dynamically loaded or unloaded.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 set_input_filter POE_FILTER
 
@@ -996,14 +996,14 @@ set_input_filter() changes a POE::Wheel::ReadWrite object's input
 filter while leaving the output filter unchanged.  This alters the way
 data is parsed without affecting how it's serialized for output.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 set_output_filter POE_FILTER
 
 set_output_filter() changes how a POE::Wheel::ReadWrite object
 serializes its output but does not affect the way data is parsed.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_input_filter
 
@@ -1014,7 +1014,7 @@ object may be introspected or altered via its own methods.
 There is no get_filter() method because there is no sane return value
 when input and output filters differ.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_output_filter
 
@@ -1025,7 +1025,7 @@ object may be introspected or altered via its own methods.
 There is no get_filter() method because there is no sane return value
 when input and output filters differ.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 set_high_mark HIGH_MARK_OCTETS
 
@@ -1038,7 +1038,7 @@ greater than HIGH_MARK_OCTETS.
 Both HighEvent and put() indicate that it's unsafe to continue writing
 when the output buffer expands to at least HIGH_MARK_OCTETS.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 set_low_mark LOW_MARK_OCTETS
 
@@ -1050,7 +1050,7 @@ POE::Wheel::ReadWrite objects will emit a LowEvent when their output
 buffers shrink to LOW_MARK_OCTETS after having reached
 HIGH_MARK_OCTETS.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 ID
 
@@ -1060,7 +1060,7 @@ stashed by its ID.  Events generated by the POE::Wheel::ReadWrite
 object will include the ID of the object, so that they may be matched
 back to their sources.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 pause_input
 
@@ -1069,7 +1069,7 @@ watching for input, and thus stop emitting InputEvent events.  It's
 much more efficient than destroying the object outright, especially if
 an application intends to resume_input() later.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 resume_input
 
@@ -1078,7 +1078,7 @@ back on.  It's used to resume watching for input, and thus resume
 sending InputEvent events.  pause_input() and resume_input() implement
 a form of input flow control, driven by the application itself.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_input_handle
 
@@ -1088,7 +1088,7 @@ Manipulating filehandles that are managed by POE may cause nasty side
 effects, which may change from one POE release to the next.  Please
 use caution.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_output_handle
 
@@ -1098,7 +1098,7 @@ Manipulating filehandles that are managed by POE may cause nasty side
 effects, which may change from one POE release to the next.  Please
 use caution.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 shutdown_input
 
@@ -1110,7 +1110,7 @@ Occasionally, the POE::Wheel::ReadWrite object will stop monitoring
 its input filehandle for new data.  This occurs regardless of the
 filehandle type.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 shutdown_output
 
@@ -1122,7 +1122,7 @@ Occasionally, the POE::Wheel::ReadWrite object will stop monitoring its
 output filehandle for new data. This occurs regardless of the
 filehandle type.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_driver_out_octets
 
@@ -1130,7 +1130,7 @@ L<POE::Driver> objects contain output buffers that are flushed
 asynchronously.  get_driver_out_octets() returns the number of octets
 remaining in the wheel's driver's output buffer.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 get_driver_out_messages
 
@@ -1142,7 +1142,7 @@ Stream-based drivers will simply return 1 if any data remains to be
 flushed.  This is because they operate with one potentially large
 message.
 
-TODO - Example.
+Z<TODO - Example.>
 
 =head2 flush
 
@@ -1165,7 +1165,7 @@ It should be obvious by now that B<this method is experimental>.  Its
 behavior may change or it may disappear outright.  Please let us know
 whether it's useful.
 
-# TODO - Example?
+Z<TODO - Example?>
 
 =head1 SEE ALSO
 
